# distributed-mean-estimation

[![PyPI](https://img.shields.io/pypi/v/distributed-mean-estimation.svg)](https://pypi.org/project/distributed-mean-estimation/)
[![Changelog](https://img.shields.io/github/v/release/amitport/distributed-mean-estimation?include_prereleases&label=changelog)](https://github.com/amitport/distributed-mean-estimation/releases)
[![License](https://img.shields.io/badge/license-MIT-blue.svg)](https://github.com/amitport/distributed-mean-estimation/blob/main/LICENSE)

Algorithms for Distributed Mean Estimation (DME) in PyTorch.

## Installation

Install this library using `pip`:

    pip install distributed-mean-estimation

## Usage

Usage instructions go here.

## Development

To contribute to this library, first checkout the code. Then create a new virtual environment:

    cd distributed-mean-estimation
    python -m venv venv
    source venv/bin/activate

Now install the dependencies and test dependencies:

    pip install -e ".[test]"

To run the tests:

    pytest
